==> analytics.js-integration-salesforce-dmp-2.0.0.tgz: package/test/index.test.js <==
'use strict'

var Analytics = require('@segment/analytics.js-core').constructor
var integration = require('@segment/analytics.js-integration')
var tester = require('@segment/analytics.js-integration-tester')
var sandbox = require('@segment/clear-env')
var SalesforceDMP = require('../lib/')

describe('Salesforce DMP', function () {
  var analytics
  var salesforceDMP
  var options = {
    confId: 'rw1to29bb',
    useV2LogicClient: false
  }

  beforeEach(function () {
    analytics = new Analytics()
    salesforceDMP = new SalesforceDMP(options)
    analytics.use(SalesforceDMP)
    analytics.use(tester)
    analytics.add(salesforceDMP)
  })

  afterEach(function () {
    analytics.restore()
    analytics.reset()
    salesforceDMP.reset()
    sandbox()
  })

  it('should have the right settings', function () {
    analytics.compare(SalesforceDMP, integration('Salesforce DMP')
      .option('confId', ''))
  })

  describe('before loading', function () {
    beforeEach(function () {
      analytics.stub(salesforceDMP, 'load')
    })

    describe('#initialize', function () {
      it('should call #load', function () {
        analytics.stub(salesforceDMP, 'load')
        analytics.initialize()
        analytics.page()
        analytics.called(salesforceDMP.load)
        analytics.assert(window.Krux)
      })
    })
  })
})

describe('Salesforce DMP V2', function () {
  var analytics
  var salesforceDMP
  var optionsV2 = {
    confId: 'rw1to29bb',
    useV2LogicClient: true,
    sendEventNames: true,
    namespace: 'test',
    trackFireEvents: ['event'],
    eventAttributeMap: { test: 'test_property' },
    contextTraitsMap: { trait: 'context_trait' }
  }

  beforeEach(function () {
    analytics = new Analytics()
    salesforceDMP = new SalesforceDMP(optionsV2)
    analytics.use(SalesforceDMP)
    analytics.use(tester)
    analytics.add(salesforceDMP)
  })

  afterEach(function () {
    analytics.restore()
    analytics.reset()
    salesforceDMP.reset()
    sandbox()
  })

  it('should have the right settings', function () {
    analytics.compare(SalesforceDMP, integration('Salesforce DMP')
      .option('confId', ''))
  })

  describe('before loading', function () {
    beforeEach(function () {
      analytics.stub(salesforceDMP, 'load')
    })

    describe('#initialize', function () {
      it('should call #load', function () {
        analytics.initialize()
        analytics.page()
        analytics.called(salesforceDMP.load)
        analytics.assert(window.Krux)
      })
    })
  })

  describe('after loading', function () {
    beforeEach(function (done) {
      analytics.once('ready', done)
      analytics.initialize()
      analytics.stub(salesforceDMP, 'load')
    })

    describe('#identify', function () {
      beforeEach(function () {
        analytics.stub(window, 'Krux')
      })

      it('should fire the Krux pixel tag', function () {
        analytics.identify()
        analytics.called(window.Krux)
      })

      it('should push Segment user ids to the dataLayer', function () {
        analytics.identify('123')
        analytics.assert(window.kruxDataLayer.segmentio_user_id === '123')
        analytics.assert(window.kruxDataLayer.segmentio_anonymous_id)
      })
    })

    describe('#track', function () {
      beforeEach(function () {
        analytics.stub(window, 'Krux')
      })

      it('should fire the Krux pixel tag', function () {
        analytics.track('event')
        analytics.called(window.Krux)
      })

      it('should push Segment anonymous id to the dataLayer', function () {
        analytics.track()
        analytics.assert(window.kruxDataLayer.segmentio_anonymous_id)
      })

      it('should not push event properties to the dataLayer if properties are not mapped in settings', function () {
        analytics.track('event', {
          property: 'value'
        })
        analytics.assert(!window.kruxDataLayer['property'])
      })

      it('should not push event properties to the dataLayer if the properties are mapped in settings, but the event is not', function () {
        analytics.track('test', {
          test: 'value'
        })
        analytics.assert(!window.kruxDataLayer['test_property'])
      })

      it('should push event properties only if both the event and property are mapped in settings', function () {
        analytics.track('event', {
          test: 'value'
        })
        analytics.assert(window.kruxDataLayer['test_property'] === 'value')
      })

      it('should push mapped contextTraits to the dataLayer', function () {
        analytics.track('event', {}, {
          context: {
            traits: {
              trait: 'value'
            }
          }
        })
        analytics.assert(window.kruxDataLayer['context_trait'] === 'value')
      })

      it('should push the event name to the dataLayer if `sendEventNames` setting is enabled', function () {
        analytics.track('event')
        analytics.assert(window.kruxDataLayer['event_name'] === 'event')
      })

      it('should not override an `event_name` that has already been pushed to the dataLayer', function () {
        window.kruxDataLayer['event_name'] = 'do not override'
        analytics.track('event')
        analytics.assert(window.kruxDataLayer['event_name'] === 'do not override')
      })
    })
  })
})

==> analytics.js-integration-salesforce-dmp-2.0.1.tgz: package/test/index.test.js <==
'use strict'

var Analytics = require('@segment/analytics.js-core').constructor
var integration = require('@segment/analytics.js-integration')
var tester = require('@segment/analytics.js-integration-tester')
var sandbox = require('@segment/clear-env')
var SalesforceDMP = require('../lib/')

describe('Salesforce DMP', function () {
  var analytics
  var salesforceDMP
  var options = {
    confId: 'rw1to29bb',
    useV2LogicClient: false
  }

  beforeEach(function () {
    analytics = new Analytics()
    salesforceDMP = new SalesforceDMP(options)
    analytics.use(SalesforceDMP)
    analytics.use(tester)
    analytics.add(salesforceDMP)
  })

  afterEach(function () {
    analytics.restore()
    analytics.reset()
    salesforceDMP.reset()
    sandbox()
  })

  it('should have the right settings', function () {
    analytics.compare(SalesforceDMP, integration('Salesforce DMP')
      .option('confId', ''))
  })

  describe('before loading', function () {
    beforeEach(function () {
      analytics.stub(salesforceDMP, 'load')
    })

    describe('#initialize', function () {
      it('should call #load', function () {
        analytics.stub(salesforceDMP, 'load')
        analytics.initialize()
        analytics.page()
        analytics.called(salesforceDMP.load)
        analytics.assert(window.Krux)
      })
    })
  })
})

describe('Salesforce DMP V2', function () {
  var analytics
  var salesforceDMP
  var optionsV2 = {
    confId: 'rw1to29bb',
    useV2LogicClient: true,
    sendEventNames: true,
    namespace: 'test',
    trackFireEvents: ['event'],
    eventAttributeMap: { test: 'test_property' },
    contextTraitsMap: { trait: 'context_trait' }
  }

  beforeEach(function () {
    analytics = new Analytics()
    salesforceDMP = new SalesforceDMP(optionsV2)
    analytics.use(SalesforceDMP)
    analytics.use(tester)
    analytics.add(salesforceDMP)
  })

  afterEach(function () {
    analytics.restore()
    analytics.reset()
    salesforceDMP.reset()
    if (window.kruxDataLayer) delete window.kruxDataLayer
    sandbox()
  })

  it('should have the right settings', function () {
    analytics.compare(SalesforceDMP, integration('Salesforce DMP')
      .option('confId', ''))
  })

  describe('before loading', function () {
    beforeEach(function () {
      analytics.stub(salesforceDMP, 'load')
    })

    describe('#initialize', function () {
      it('should call #load', function () {
        analytics.initialize()
        analytics.page()
        analytics.called(salesforceDMP.load)
        analytics.assert(window.Krux)
      })
    })
  })

  describe('after loading', function () {
    beforeEach(function (done) {
      analytics.once('ready', done)
      analytics.initialize()
      analytics.stub(salesforceDMP, 'load')
    })

    describe('#identify', function () {
      beforeEach(function () {
        analytics.stub(window, 'Krux')
      })

      it('should fire the Krux pixel tag', function () {
        analytics.identify()
        analytics.called(window.Krux)
      })

      it('should push Segment user ids to the dataLayer', function () {
        analytics.identify('123')
        analytics.assert(window.kruxDataLayer.segmentio_user_id === '123')
        analytics.assert(window.kruxDataLayer.segmentio_anonymous_id)
      })
    })

    describe('#track', function () {
      beforeEach(function () {
        analytics.stub(window, 'Krux')
      })

      it('should fire the Krux pixel tag', function () {
        analytics.track('event')
        analytics.called(window.Krux)
      })

      it('should push Segment anonymous id to the dataLayer', function () {
        analytics.track('event')
        analytics.assert(window.kruxDataLayer.segmentio_anonymous_id)
      })

      it('should not push event properties to the dataLayer if properties are not mapped in settings', function () {
        analytics.track('event', {
          property: 'value'
        })
        analytics.assert(!window.kruxDataLayer['property'])
      })

      it('should not create a dataLayer if the Segment track event is not mapped in settings', function () {
        analytics.track('test', {
          test: 'value'
        })
        analytics.assert(!window.kruxDataLayer)
      })

      it('should push event properties only if both the event and property are mapped in settings', function () {
        analytics.track('event', {
          test: 'value'
        })
        analytics.assert(window.kruxDataLayer['test_property'] === 'value')
      })

      it('should push mapped contextTraits to the dataLayer', function () {
        analytics.track('event', {}, {
          context: {
            traits: {
              trait: 'value'
            }
          }
        })
        analytics.assert(window.kruxDataLayer['context_trait'] === 'value')
      })

      it('should push the event name to the dataLayer if `sendEventNames` setting is enabled', function () {
        analytics.track('event')
        analytics.assert(window.kruxDataLayer['event_name'] === 'event')
      })

      it('should not override an `event_name` that has already been pushed to the dataLayer', function () {
        window.kruxDataLayer = {}
        window.kruxDataLayer['event_name'] = 'do not override'
        analytics.track('event')
        analytics.assert(window.kruxDataLayer['event_name'] === 'do not override')
      })
    })
  })
})
